from setuptools import setup, find_packages

setup(
    name='daalab',
    version='0.8',
    packages=find_packages(),
    install_requires=[], 
    author='Imad',
    author_email='mdimad005@gmail.com',
    description='A Python library for all daa lab questions',
)
